@@ -26,7 +26,6 @@
 #include <ctype.h>
 
 #include "gst.h"
-#include "gst-hig-dialog.h"
 #include "boot-druid.h"
 #include "boot-settings.h"
 #include "callbacks.h"
@@ -106,13 +105,13 @@ druid_show_error (BootDruid *druid, gchar *text)
 {
 	GtkWidget *d;
 
-	d = gst_hig_dialog_new (GTK_WINDOW (druid),
-				GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-				GST_HIG_MESSAGE_ERROR,
-				_("Error creating boot image"),
-				text,
-				GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
-				NULL);
+	d = gtk_message_dialog_new (GTK_WINDOW (druid),
+				    GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+				    GTK_MESSAGE_ERROR,
+				    GTK_BUTTONS_CLOSE,
+				    _("Error creating boot image"));
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (d), text);
+
 	gtk_dialog_run (GTK_DIALOG (d));
 	gtk_widget_destroy (d);
 }
@@ -256,12 +255,13 @@ other_next (GnomeDruidPage *page, GnomeDruid *druid, gpointer data)
 static void
 image_check (BootDruid *druid)
 {
-	const gchar *buf = gtk_entry_get_text (druid->gui->image_entry);
+	const gchar *buf = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (druid->gui->image_widget));
 	const gchar *buf2 = gtk_entry_get_text (GTK_ENTRY (GTK_BIN (druid->gui->root)->child));
-	gboolean enabled = ((strlen (buf) > 0) && (strlen (buf2) > 0))?TRUE : FALSE;
+	gboolean enabled = (buf && buf2 && (strlen (buf) > 0) && (strlen (buf2) > 0)) ? TRUE : FALSE;
 	
 	/* TODO: Improve check */ 
 	gnome_druid_set_buttons_sensitive (druid->druid, TRUE, enabled, TRUE, FALSE);
+	g_free (buf);
 }
 
 static void
@@ -281,7 +281,7 @@ image_prepare (GnomeDruidPage *page, GnomeDruid *druid, gpointer data)
 	gtk_window_set_title (GTK_WINDOW (config), title);
 	g_free (title);
 
-	gtk_widget_grab_focus (GTK_WIDGET (config->gui->image_entry));
+	gtk_widget_grab_focus (GTK_WIDGET (config->gui->image_widget));
 	g_signal_stop_emission_by_name (page, "prepare");
 	image_check (config);
 }
@@ -503,7 +503,7 @@ construct (BootDruid *druid)
 	g_signal_connect (G_OBJECT (druid->gui->type), "changed",
 			  G_CALLBACK (identity_changed), druid);
 	
-	g_signal_connect (G_OBJECT (druid->gui->image_entry), "changed",
+	g_signal_connect (G_OBJECT (druid->gui->image_widget), "selection-changed",
 			  G_CALLBACK (image_changed), druid);
 	g_signal_connect (G_OBJECT (GTK_BIN (druid->gui->root)->child), "changed",
 			  G_CALLBACK (image_changed), druid);
