@@ -33,6 +33,7 @@ enable_iface (GstIface *iface)
   gboolean   success;
 
   success = gst_iface_enable (iface);
+  gst_iface_set_auto (iface, success);
 
   if (!success)
     {
@@ -120,15 +121,10 @@ on_iface_active_changed (GtkWidget *widget, gpointer data)
   GstConnectionDialog *dialog;
   gboolean active;
 
-  active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
   dialog = GST_NETWORK_TOOL (tool)->dialog;
+  active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
 
-  gtk_widget_set_sensitive (dialog->wireless_frame, active);
-  gtk_widget_set_sensitive (dialog->ethernet_frame, active);
-  gtk_widget_set_sensitive (dialog->plip_frame,     active);
-  gtk_widget_set_sensitive (dialog->modem_frame,    active);
-  gtk_widget_set_sensitive (dialog->account_page,   active);
-  gtk_widget_set_sensitive (dialog->options_page,   active);
+  connection_dialog_set_sensitive (dialog, active);
 }
 
 void
@@ -342,13 +338,22 @@ enable_disable_iface (GstNetworkTool *network_tool, gboolean enable)
       if (enable)
 	enable_iface (iface);
       else
-	gst_iface_disable (iface);
+        {
+	  gst_iface_disable (iface);
+	  gst_iface_set_auto (iface, FALSE);
+	}
 
       ifaces_model_modify_interface_at_iter (&iter);
       g_object_unref (iface);
 
       /* we need this to update the buttons state */
       g_signal_emit_by_name (G_OBJECT (selection), "changed");
+
+      /* update gateway settings */
+      if (gtk_combo_box_get_active (network_tool->gateways_list) == -1)
+	gtk_combo_box_set_active (network_tool->gateways_list, 0);
+
+      gst_dialog_modify (tool->main_dialog);
     }
 }
 
@@ -403,6 +408,12 @@ on_host_aliases_delete_clicked (GtkWidget *widget, gpointer data)
     }
 }
 
+void
+on_host_aliases_dialog_changed (GtkWidget *widget, gpointer data)
+{
+  host_aliases_check_fields ();
+}
+
 void
 on_dialog_changed (GtkWidget *widget, gpointer data)
 {
@@ -474,3 +485,34 @@ on_ip_address_focus_out (GtkWidget *widget, GdkEventFocus *event, gpointer data)
   connection_check_netmask (dialog->address, dialog->netmask);
   return FALSE;
 }
+
+void
+on_gateway_combo_changed (GtkWidget *widget, gpointer data)
+{
+  GtkTreeModel *model;
+  GtkTreeIter   iter;
+  GstIface     *iface;
+  gchar        *dev, *gateway;
+
+  if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (widget), &iter))
+    {
+      model = gtk_combo_box_get_model (GTK_COMBO_BOX (widget));
+
+      gtk_tree_model_get (model, &iter,
+			  COL_OBJECT, &iface,
+			  -1);
+
+      /* FIXME: this won't work for DHCP nor PPP ifaces */
+      g_object_get (G_OBJECT (iface),
+		    "iface-dev", &dev,
+		    "iface-gateway", &gateway,
+		    NULL);
+
+      if (dev && gateway)
+	gst_tool_run_set_directive (tool, NULL, NULL,
+				    "set_gateway", dev, gateway, NULL);
+
+      g_free (dev);
+      g_free (gateway);
+    }
+}
