@@ -29,6 +29,7 @@
 enum {
 	COL_ACTIVE,
 	COL_SERVICE,
+	COL_PRIORITY,
 	COL_POINTER,
 	COL_LAST
 };
@@ -38,7 +39,7 @@ enum {
 };
 
 void			table_create				(void);
-void			table_populate				(xmlNodePtr, gint);
+void			table_populate				(xmlNodePtr, gchar*);
 void                    table_empty                             (void);
 
 #endif /* _TABLE_H */
